<template>
    <div class="fixed-assets">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-固定资产.png')" title="固定资产价值" routerPath="/platLayout/FixedAsset"/>
        <div class="bottom-chart">
            <div id="fixed-chart"></div>
        </div>
    </div>
</template>

<script>
import * as echarts from 'echarts'
import utils from '@/utils.js'
import api from '@/api/homePage.js'
import PublicTitle from '@/components/PublicTitle/index'
export default {
    name: 'FixedAssets', // 固定资产价值
    components: { PublicTitle },
    data() {
        return {
            echartsData: []
        }
    },
    created() {
        this.getFixedAssets()
    },
    mounted() {
    },
    methods: {
        getFixedAssets() {
            api.fixedStatistics({}, res => {
                if (res.state) {
                    this.echartsData = res.value
                }
                this.initChat()
            })
        },
        initChat() {
            let indicatorData=[]
            let nums=[]
            this.echartsData.forEach(e => {
                indicatorData.push({
                    name:e.level,
                    max:25000
                })
                nums.push(e.count)
            });
            let chartDom = echarts.init(document.getElementById('fixed-chart'))
            let option = {
                radar: {
                    radius: '75%',
                    startAngle: -240,

                    indicator: indicatorData,
                },
                tooltip: {
                    show: true, // 显示提示框
                    trigger: 'item', // 触发类型为数据项
                },
                series: [
                    {
                        type: 'radar',
                        symbolSize: 6,
                        itemStyle: {
                            color: '#198cff',
                        },
                        areaStyle: {
                            color: 'rgba(25, 140, 255, 0.3)',
                        },
                        data: [
                            {
                                value: nums,
                                name: '固定资产价值',
                            },
                        ],
                    },
                ],
            }
            chartDom.setOption(option)
            window.addEventListener('resize', () => {
                chartDom.resize()
            })
        },
    },
}
</script>

<style scoped lang="scss">
.fixed-assets {
    width: 100%;
    height: 100%;
    padding: 16px;
    box-sizing: border-box;
    background: #ffffff;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;

    .bottom-chart {
        width: 100%;
        height: calc(100% - 14px);

        #fixed-chart {
            width: 100%;
            height: 100%;
        }
    }
}
</style>
